@@ -44,7 +44,7 @@ def pytest_addoption(parser):
         help=(
             "Remote connection backend (paramiko, ssh, safe-ssh, "
             "salt, docker, ansible, podman)"
-        )
+        ),
     )
     group.addoption(
         "--hosts",
@@ -87,8 +87,9 @@ def pytest_addoption(parser):
         action="store_true",
         dest="force_ansible",
         help=(
-            'Force use of ansible connection backend only (slower but all '
-            'ansible connection options are handled)')
+            "Force use of ansible connection backend only (slower but all "
+            "ansible connection options are handled)"
+        ),
     )
     group.addoption(
         "--nagios",
@@ -119,11 +120,11 @@ def pytest_generate_tests(metafunc):
         params = sorted(params, key=lambda x: x.backend.get_pytest_id())
         ids = [e.backend.get_pytest_id() for e in params]
         metafunc.parametrize(
-            "_testinfra_host", params, ids=ids, scope="module", indirect=True)
+            "_testinfra_host", params, ids=ids, scope="module", indirect=True
+        )
 
 
 class NagiosReporter:
-
     def __init__(self, out):
         self.passed = 0
         self.failed = 0
@@ -143,34 +144,34 @@ class NagiosReporter:
 
     def report(self):
         if self.failed:
-            status = b'CRITICAL'
+            status = b"CRITICAL"
             ret = 2
         else:
-            status = b'OK'
+            status = b"OK"
             ret = 0
 
-        if hasattr(sys.stdout, 'buffer'):
-            out = sys.stdout.buffer
-        else:
-            out = sys.stdout
-
-        out.write((
-            b"TESTINFRA %s - %d passed, %d failed, %d skipped in %.2f "
-            b"seconds\n") % (
-                status, self.passed, self.failed, self.skipped,
-                time.time() - self.start_time))
+        out = sys.stdout.buffer
+        out.write(
+            (b"TESTINFRA %s - %d passed, %d failed, %d skipped in %.2f " b"seconds\n")
+            % (
+                status,
+                self.passed,
+                self.failed,
+                self.skipped,
+                time.time() - self.start_time,
+            )
+        )
         self.out.seek(0)
         shutil.copyfileobj(self.out, out)
         return ret
 
 
 class SpooledTemporaryFile(tempfile.SpooledTemporaryFile):
-
     def __init__(self, *args, **kwargs):
-        if 'b' in kwargs.get('mode', 'b'):
-            self._out_encoding = kwargs.pop('encoding')
+        if "b" in kwargs.get("mode", "b"):
+            self._out_encoding = kwargs.pop("encoding")
         else:
-            self._out_encoding = kwargs.get('encoding')
+            self._out_encoding = kwargs.get("encoding")
         super().__init__(*args, **kwargs)
 
     def write(self, s):
@@ -190,18 +191,17 @@ def pytest_configure(config):
         logging.getLogger("testinfra").setLevel(logging.DEBUG)
     if config.option.nagios:
         # disable & re-enable terminalreporter to write in a tempfile
-        reporter = config.pluginmanager.getplugin('terminalreporter')
+        reporter = config.pluginmanager.getplugin("terminalreporter")
         if reporter:
             out = SpooledTemporaryFile(encoding=sys.stdout.encoding)
             config.pluginmanager.unregister(reporter)
             reporter = reporter.__class__(config, out)
-            config.pluginmanager.register(reporter, 'terminalreporter')
-            config.pluginmanager.register(NagiosReporter(out),
-                                          'nagiosreporter')
+            config.pluginmanager.register(reporter, "terminalreporter")
+            config.pluginmanager.register(NagiosReporter(out), "nagiosreporter")
 
 
 @pytest.mark.trylast
 def pytest_sessionfinish(session, exitstatus):
-    reporter = session.config.pluginmanager.getplugin('nagiosreporter')
+    reporter = session.config.pluginmanager.getplugin("nagiosreporter")
     if reporter:
         session.exitstatus = reporter.report()
